Dragées - mariage, baptême - contenants, boites dragées - Confiserie Massardier
Description: Dragées Massardier : Dragées mariage et contenant baptême ou communion. Nos kits dragées uniques et originales, ballotins, boites et accessoires dragées. Thème dragées mariage, Thème dragées baptême
Keywords: dragées,dragées mariage,dragées baptême,dragées communion,boite mariage,dragées chocolat,dragées amandes,dragées avola,contenant dragées,ballotins dragées, kit dragées

Votre panier - Satisfait ou remboursé, 14 jours pour changer

| Panier

0 article(s)
Recherche

Recherche avancée

Création de compte
Vos Coordonnées
*Civilité : | Mlle Mme M.
*Nom : |
*Prénom : |
Vous êtes : | Un particulier Une entreprise
* Société |
*Adresse : |
*Pays : | Pour les codes postaux militaires, veuillez sélectionner "France ARMEES".
*Code postal : |
*Frais d'envoi : | -
*Ville : |
*E-mail : |
*Confirmer l'E-mail : |
*Téléphone : |
Téléphone portable : |
Fax : |
Commentaires : | Indiquez ci-dessus toute information que vous jugez utile.
Mot de passe d'accès à votre compte
Choisissez un mot de passe dont vous vous souviendrez. Ce mot de passe sera nécessaire pour accéder à votre compte.
*Votre mot de passe : |
*Confirmer le mot de passe : |
| Je souhaite être tenu(e) informé(e) de vos nouveautés.
| Je souhaite recevoir des informations sur des produits associés émanant de sociétés partenaires (**).
Vous disposez d'un droit d'accès, de modification, de rectification et de suppression des données vous concernant (Art. 34 de la loi informatiques et libertés). Pour exercer ce droit, contactez-nous : CONFISERIE MASSARDIER Zone Corata 4 chemin du Pourquier 30250 Sommières FRANCE Tél. : 04.66.93.80.04 Fax : E-mail : daniel@dragees-massardier.fr Siret : 413 256 397 00030 Code APE/NAF : 4791B / Vente à distance sur catalogue spécialisé TVA intra-communautaire : FR78413256397 Num CNIL : 1587031 (*) Les champs marqués d'un astérisque sont obligatoires pour votre inscription (**) Si cette case est cochée, vos coordonnées peuvent être transmises à des tiers par notre intermédiaire |